@@ -33,6 +33,8 @@
 //! # Usage
 //!
 //! ```rust
+//! # #[cfg(feature = "std")]
+//! # {
 //! use crypto_box::{Box, PublicKey, SecretKey, aead::Aead};
 //!
 //! //
@@ -41,7 +43,7 @@
 //!
 //! // Generate a random secret key.
 //! // NOTE: It can be serialized as bytes by calling `secret_key.to_bytes()`
-//! let mut rng = rand_core::OsRng;
+//! let mut rng = crypto_box::rand_core::OsRng;
 //! let alice_secret_key = SecretKey::generate(&mut rng);
 //!
 //! // Get the public key for the secret key we just generated
@@ -92,6 +94,7 @@
 //! let decrypted_plaintext = bob_box.decrypt(&nonce, &ciphertext[..]).unwrap();
 //!
 //! assert_eq!(&plaintext[..], &decrypted_plaintext[..]);
+//! # }
 //! ```
 //!
 //! ## Choosing `ChaChaBox` vs `SalasaBox`
@@ -100,9 +103,11 @@
 //! field. To specify customized AD, you can use `crypto_box::ChaChaBox` instead.
 //!
 //! ```rust
+//! # #[cfg(feature = "std")]
+//! # {
 //! use crypto_box::{ChaChaBox, PublicKey, SecretKey, aead::{Aead, Payload}};
 //!
-//! let mut rng = rand_core::OsRng;
+//! let mut rng = crypto_box::rand_core::OsRng;
 //! let alice_secret_key = SecretKey::generate(&mut rng);
 //! let alice_public_key_bytes = alice_secret_key.public_key().as_bytes().clone();
 //! let bob_public_key = PublicKey::from([
@@ -144,6 +149,7 @@
 //! }).unwrap();
 //!
 //! assert_eq!(&plaintext[..], &decrypted_plaintext[..]);
+//! }
 //! ```
 //!
 //! ## In-place Usage (eliminates `alloc` requirement)
@@ -180,6 +186,7 @@
 )]
 #![warn(missing_docs, rust_2018_idioms)]
 
+pub use rand_core;
 pub use xsalsa20poly1305::{aead, generate_nonce};
 
 use chacha20::hchacha;
